@@ -59,25 +59,27 @@ class LupusecAPI:
         self._auth = None
         if self._username != None and self._password != None:
             self._auth = aiohttp.BasicAuth(login=self._username, password=self._password, encoding='utf-8')
-        self._session = aiohttp.ClientSession(auth=self._auth)
+        # self._session = aiohttp.ClientSession(auth=self._auth)
         self._system = None
 
 
-    async def _async_api_call(client, url) -> Dict:
+    async def _async_api_call(client, url):
         """Generic sync method to call the Lupusec API"""
-        _LOGGER.debug("_async_api_call() called: ")
+        _LOGGER.debug("_async_api_call() called: URL=%s", url)
 
         try:
+            _LOGGER.debug("try...")
             async with client.get(url) as resp:
-                _LOGGER.debug("  API-Call: %s", url)
-                if response.status != 200:
-                    _LOGGER.error(f"Response status: {response.status}")
-                    return {}                
-                print(resp.status)
+                #_LOGGER.debug("  API-Call: %s", url)
+                #if resp.status != 200:
+                #    _LOGGER.error(f"Response status: {resp.status}")
+                #    return {}                
+                #print(resp.status)
                 content = await resp.json(content_type=None)
                 print("type of response: ", type(content))
-                print("API-Call finished:")
+                print("API-Call finished.")
                 return content
+
         except aiohttp.client_exceptions.ClientConnectorError:
             _LOGGER.error("Cannot connect to: ", url)
             return {}
@@ -87,7 +89,6 @@ class LupusecAPI:
             return {}
 
 
-
     async def async_get_system(self) -> None:
         """Async method to get the system info."""
         _LOGGER.debug("__init__.py.async_get_system() called: ")
@@ -110,23 +111,25 @@ class LupusecAPI:
         #    return devices.system.LupusecSystem(data)
 
         # new approach
-        async with self._session as client:
+        async with aiohttp.ClientSession(auth=self._auth) as client:
             tasks = []
 
             # LOGIN_REQUEST
-            _LOGGER.debug("__init__.py.async_get_system(): LOGIN_REQUEST=", CONST.LOGIN_REQUEST)
-            tasks.append(asyncio.ensure_future(_async_api_call(client, CONST.LOGIN_REQUEST)))
+            _LOGGER.debug("__init__.py.async_get_system(): LOGIN_REQUEST=%s", CONST.LOGIN_REQUEST)
+            tasks.append(asyncio.ensure_future(LupusecAPI._async_api_call(client, CONST.LOGIN_REQUEST)))
             # INFO_REQUEST
-            _LOGGER.debug("__init__.py.async_get_system(): INFO_REQUEST=", CONST.INFO_REQUEST)
-            tasks.append(asyncio.ensure_future(_async_api_call(client, CONST.INFO_REQUEST)))
+            _LOGGER.debug("__init__.py.async_get_system(): INFO_REQUEST=%s", CONST.INFO_REQUEST)
+            tasks.append(asyncio.ensure_future(LupusecAPI._async_api_call(client, CONST.INFO_REQUEST)))
 
+            # Print response list
+            _LOGGER.debug("await asyncio.gather(*tasks)...")
             response_list = await asyncio.gather(*tasks)
+            _LOGGER.debug("done. check content in response_list...")
             for content in response_list:
                 print(content)
-                _LOGGER.debug("Response Content:", content)
+                _LOGGER.debug("Response Content: ", content)
             # return devices.system.LupusecSystem(content)
 
-
             # try to parse json response
             # try:
             #     json_data = json.loads(data)["updates"]
